@@ -244,7 +244,7 @@ def attach_snapshot(snap, key_pair=None, security_groups='', inst=None,
             for vol in volumes:
                 if vol.status != 'available':
                     vol.detach(force=True)
-                wait_for(vol, 'available')
+                wait_for(vol, 'available', limit=10 * 60)
                 logger.info('Deleting {vol} in {vol.region}.'.format(vol=vol))
                 vol.delete()
 
@@ -595,7 +595,7 @@ def launch_instance_from_ami(
         instance_type=inst_type,
         user_data=user_data,
         placement=zone_name).instances[0]
-    wait_for(inst, 'running')
+    wait_for(inst, 'running', limit=10 * 60)
     groups = [grp.name for grp in inst.groups]
     inst.add_tag('Security Groups', dumps(groups, separators=(',', ':')))
     add_tags(inst, image.tags)
